@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -151,7 +151,6 @@ void CUpDownClient::Init()
 	m_cAsked = 0;
 	msReceivedPrev = 0;
 	kBpsDown = 0.0;
-	fDownAvgFilter = 1.0;
 	bytesReceivedCycle = 0;
 	m_nServerPort = 0;
 	m_iFileListRequested = 0;
@@ -2539,7 +2538,6 @@ void CUpDownClient::SendFirewallCheckUDPRequest()
 		return;
 	}
 
-	wxASSERT(Kademlia::CKademlia::GetPrefs()->GetExternalKadPort() != 0);
 	CMemFile data;
 	data.WriteUInt16(Kademlia::CKademlia::GetPrefs()->GetInternKadPort());
 	data.WriteUInt16(Kademlia::CKademlia::GetPrefs()->GetExternalKadPort());
