@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -231,6 +231,7 @@ void CDownloadListCtrl::AddFile( CPartFile* file )
 		// Check if the new file is visible in the current category
 		if ( file->CheckShowItemInGivenCat( m_category ) ) {
 			ShowFile( file, true );
+			SortList();
 		}
 	}
 }
@@ -479,6 +480,8 @@ void CDownloadListCtrl::ShowSources( CPartFile* file, bool show )
 		for ( it = a4afSources.begin(); it != a4afSources.end(); ++it ) {
 			AddSource( file, *it, A4AF_SOURCE );
 		}
+
+		SortList();
 	} else {
 		for ( int i = GetItemCount() - 1; i >= 0; --i ) {
 			CtrlItem_Struct* item = (CtrlItem_Struct*)GetItemData(i);
@@ -908,24 +911,19 @@ void CDownloadListCtrl::OnMouseRightClick(wxListEvent& evt)
 		m_menu->AppendSeparator();
 		//-----------------------------------------------------
 		wxMenu* extendedmenu = new wxMenu();
-		extendedmenu->Append(MP_SWAP_A4AF_TO_THIS,
-			_("Swap every A4AF to this file now"));
-		extendedmenu->AppendCheckItem(MP_SWAP_A4AF_TO_THIS_AUTO,
-			_("Swap every A4AF to this file (Auto)"));
+		extendedmenu->Append(MP_SWAP_A4AF_TO_THIS, _("Swap every A4AF to this file now"));
+		extendedmenu->AppendCheckItem(MP_SWAP_A4AF_TO_THIS_AUTO, _("Swap every A4AF to this file (Auto)"));
 		//-----------------------------------------------------
 		extendedmenu->AppendSeparator();
 		//-----------------------------------------------------
-		extendedmenu->Append(MP_SWAP_A4AF_TO_ANY_OTHER,
-			_("Swap every A4AF to any other file now"));
+		extendedmenu->Append(MP_SWAP_A4AF_TO_ANY_OTHER, _("Swap every A4AF to any other file now"));
 		//-----------------------------------------------------
-		m_menu->Append(MP_MENU_EXTD,
-			_("Extended Options"), extendedmenu);
+		m_menu->Append(MP_MENU_EXTD, _("Extended Options"), extendedmenu);
 		//-----------------------------------------------------
 		m_menu->AppendSeparator();
 		//-----------------------------------------------------
 /* Commented out till RB2 is back 
-		m_menu->Append( MP_RAZORSTATS,
-			_("Get Razorback 2's stats for this file"));
+		m_menu->Append( MP_RAZORSTATS, _("Get Razorback 2's stats for this file"));
 		//-----------------------------------------------------
 		m_menu->AppendSeparator();
 		//-----------------------------------------------------
@@ -937,12 +935,9 @@ void CDownloadListCtrl::OnMouseRightClick(wxListEvent& evt)
 		//-----------------------------------------------------
 		m_menu->AppendSeparator();
 		//-----------------------------------------------------
-		m_menu->Append(MP_GETMAGNETLINK,
-			_("Copy magnet URI to clipboard"));
-		m_menu->Append(MP_GETED2KLINK,
-			_("Copy eD2k &link to clipboard"));
-		m_menu->Append(MP_WS,
-			_("Copy feedback to clipboard"));
+		m_menu->Append(MP_GETMAGNETLINK, _("Copy magnet URI to clipboard"));
+		m_menu->Append(MP_GETED2KLINK, _("Copy eD2k &link to clipboard"));
+		m_menu->Append(MP_WS, _("Copy feedback to clipboard"));
 		//-----------------------------------------------------
 		m_menu->AppendSeparator();
 		//-----------------------------------------------------	
@@ -1004,37 +999,35 @@ void CDownloadListCtrl::OnMouseRightClick(wxListEvent& evt)
 
 		int priority = file->IsAutoDownPriority() ?
 			PR_AUTO : file->GetDownPriority();
-		
+
 		priomenu->Check( MP_PRIOHIGH,	priority == PR_HIGH );
 		priomenu->Check( MP_PRIONORMAL, priority == PR_NORMAL );
 		priomenu->Check( MP_PRIOLOW,	priority == PR_LOW );
 		priomenu->Check( MP_PRIOAUTO,	priority == PR_AUTO );
 
 		menu->Enable( MP_MENU_EXTD, canPause );
-	
-		PopupMenu(m_menu, evt.GetPoint());
-
 	} else {
 		CUpDownClient* client = item->GetSource();
-		
+
 		m_menu = new wxMenu(wxT("Clients"));
 		m_menu->Append(MP_DETAIL, _("Show &Details"));
 		m_menu->Append(MP_ADDFRIEND, client->IsFriend() ? _("Remove from friends") : _("Add to Friends"));
 		m_menu->Append(MP_SHOWLIST, _("View Files"));
 		m_menu->Append(MP_SENDMESSAGE, _("Send message"));
 		m_menu->Append(MP_CHANGE2FILE, _("Swap to this file"));
-		
+
 		// Only enable the Swap option for A4AF sources
 		m_menu->Enable(MP_CHANGE2FILE, (item->GetType() == A4AF_SOURCE));
 		// We need a valid IP if we are to message the client
 		m_menu->Enable(MP_SENDMESSAGE, (client->GetIP() != 0));
-		
+
 		m_menu->Enable(MP_SHOWLIST, !client->HasDisabledSharedFiles());
-		
-		PopupMenu(m_menu, evt.GetPoint());
-					
 	}
-	
+
+	bool autosort = thePrefs::AutoSortDownload(false);
+	PopupMenu(m_menu, evt.GetPoint());
+	thePrefs::AutoSortDownload(autosort);
+
 	delete m_menu;
 	m_menu = NULL;
 	
@@ -1050,12 +1043,14 @@ void CDownloadListCtrl::OnMouseMiddleClick(wxListEvent& evt)
 	}
 
 	CtrlItem_Struct* item = (CtrlItem_Struct*)GetItemData( index );
-	
+
+	bool autosort = thePrefs::AutoSortDownload(false);
 	if ( item->GetType() == FILE_TYPE ) {
 		CFileDetailDialog(this, item->GetFile()).ShowModal();
 	} else {
 		CClientDetailDialog(this, item->GetSource()).ShowModal();
 	}
+	thePrefs::AutoSortDownload(autosort);
 }
 
 
@@ -1826,6 +1821,11 @@ int CDownloadListCtrl::Compare( const CPartFile* file1, const CPartFile* file2,
 		result = CmpAny(
 			file1->GetFileName(),
 			file2->GetFileName() );
+		// Filename shouldn't be equal. If it IS, definitely choose one, so comparison result
+		// is always defined. (Fallback in MuleListCtrl is wrong for client comparison.)
+		if (!result) {
+			result = CmpAny(file1, file2);
+		}
 		break;
 
 	// Sort by size
@@ -2042,6 +2042,27 @@ void CDownloadListCtrl::ClearCompleted()
 }
 
 
+void CDownloadListCtrl::ResetCatParts(uint8 cat)
+{
+	// Go through all files
+	for ( ListItems::iterator it = m_ListItems.begin(); it != m_ListItems.end(); ) {
+		CtrlItem_Struct* item = it->second; ++it;
+		
+		if ( item->GetType() == FILE_TYPE ) {
+			CPartFile* file = item->GetFile();
+			
+			if ( file->GetCategory() == cat ) {
+				// Reset the category
+				file->SetCategory( 0 );
+			} else if ( file->GetCategory() > cat ) {
+				// Set to the new position of the original category
+				file->SetCategory( file->GetCategory() - 1 );
+			}
+		}
+	}
+}
+
+
 void CDownloadListCtrl::ShowFilesCount( int diff )
 {
 	m_filecount += diff;
