@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -129,27 +129,21 @@ void CDownloadQueue::LoadMetFiles(const CPath& path)
 	// Load part-files	
 	for ( size_t i = 0; i < files.size(); i++ ) {
 		printf("\rLoading PartFile %u of %u", (unsigned int)(i + 1), (unsigned int)files.size());
-			
 		fileName = files[i].GetFullName();
-		
-		CPartFile* toadd = new CPartFile();
-		bool result = (toadd->LoadPartFile(path, fileName) != 0);
+		CPartFile *toadd = new CPartFile();
+		bool result = toadd->LoadPartFile(path, fileName) != 0;
 		if (!result) {
 			// Try from backup
-			result = (toadd->LoadPartFile(path, fileName, true) != 0);
+			result = toadd->LoadPartFile(path, fileName, true) != 0;
 		}
-		
 		if (result && !IsFileExisting(toadd->GetFileHash())) {
 			{
 				wxMutexLocker lock(m_mutex);
 				m_filelist.push_back(toadd);
 			}
-		
-			NotifyObservers( EventType( EventType::INSERTED, toadd ) );
+			NotifyObservers(EventType(EventType::INSERTED, toadd));
 			Notify_DownloadCtrlAddFile(toadd);
 		} else {
-			delete toadd;
-			
 			wxString msg;
 			if (result) {
 				msg << CFormat(wxT("WARNING: Duplicate partfile with hash '%s' found, skipping: %s"))
@@ -160,14 +154,15 @@ void CDownloadQueue::LoadMetFiles(const CPath& path)
 					_("ERROR: Failed to load backup file. Search http://forum.amule.org for .part.met recovery solutions."));
 				msg << CFormat(wxT("ERROR: Failed to load PartFile '%s'")) % fileName;
 			}
-			
 			AddDebugLogLineM(true, logPartFile, msg);
 			
 			// Newline so that the error stays visible.
 			printf(": %s\n", (const char*)unicode2char(msg));
+
+			// Delete the partfile object in the end.
+			delete toadd;
 		}
 	}
-
 	printf("\nAll PartFiles Loaded.\n");
 	
 	if ( GetFileCount() == 0 ) {
@@ -220,7 +215,7 @@ void CDownloadQueue::LoadSourceSeeds()
 	}
 }
 
-//#warning We must add the sources, review CSearchFile constructor.
+
 void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd, uint8 category)
 {
 	if ( IsFileExisting(toadd->GetFileHash()) ) {
@@ -246,6 +241,23 @@ void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd, uint8 category)
 	
 	if ( newfile && newfile->GetStatus() != PS_ERROR ) {
 		AddDownload( newfile, thePrefs::AddNewFilesPaused(), category );
+		// Add any possible sources
+		if (toadd->GetClientID() && toadd->GetClientPort()) {
+			CMemFile sources(1+4+2);
+			sources.WriteUInt8(1);
+			sources.WriteUInt32(toadd->GetClientID());
+			sources.WriteUInt16(toadd->GetClientPort());
+			sources.Reset();
+			newfile->AddSources(sources, toadd->GetClientServerIP(), toadd->GetClientServerPort(), SF_SEARCH_RESULT, false);
+		}
+		for (std::list<CSearchFile::ClientStruct>::const_iterator it = toadd->GetClients().begin(); it != toadd->GetClients().end(); ++it) {
+			CMemFile sources(1+4+2);
+			sources.WriteUInt8(1);
+			sources.WriteUInt32(it->m_ip);
+			sources.WriteUInt16(it->m_port);
+			sources.Reset();
+			newfile->AddSources(sources, it->m_serverIP, it->m_serverPort, SF_SEARCH_RESULT, false);
+		}
 	} else {
 		delete newfile;
 	}
@@ -1040,22 +1052,6 @@ void CDownloadQueue::AddLinksFromFile()
 }
 
 
-void CDownloadQueue::ResetCatParts(uint8 cat)
-{
-	for ( uint16 i = 0; i < GetFileCount(); i++ ) {
-		CPartFile* file = GetFileByIndex( i );
-		
-		if ( file->GetCategory() == cat ) {
-			// Reset the category
-			file->SetCategory( 0 );
-		} else if ( file->GetCategory() > cat ) {
-			// Set to the new position of the original category
-			file->SetCategory( file->GetCategory() - 1 );
-		}
-	}
-}
-
-
 void CDownloadQueue::SetCatPrio(uint8 cat, uint8 newprio)
 {
 	for ( uint16 i = 0; i < GetFileCount(); i++ ) {
@@ -1446,42 +1442,41 @@ void CDownloadQueue::ObserverAdded( ObserverType* o )
 	NotifyObservers( EventType( EventType::INITIAL, &list ), o );
 }
 
-void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt128* pcontactID, const Kademlia::CUInt128* pbuddyID, uint8 type, uint32 ip, uint16 tcp, uint16 udp, uint32 serverip, uint16 serverport, uint8 byCryptOptions)
+void CDownloadQueue::KademliaSearchFile(uint32_t searchID, const Kademlia::CUInt128* pcontactID, const Kademlia::CUInt128* pbuddyID, uint8_t type, uint32_t ip, uint16_t tcp, uint16_t udp, uint32_t buddyip, uint16_t buddyport, uint8_t byCryptOptions)
 {
-	
 	AddDebugLogLineM(false, logKadSearch, wxString::Format(wxT("Search result sources (type %i)"),type));
-	
+
 	//Safety measure to make sure we are looking for these sources
 	CPartFile* temp = GetFileByKadFileSearchID(searchID);
 	if( !temp ) {
 		AddDebugLogLineM(false, logKadSearch, wxT("This is not the file we're looking for..."));
 		return;
 	}
-	
+
 	//Do we need more sources?
 	if(!(!temp->IsStopped() && thePrefs::GetMaxSourcePerFile() > temp->GetSourceCount())) {
 		AddDebugLogLineM(false, logKadSearch, wxT("No more sources needed for this file"));
 		return;
 	}
 
-	uint32 ED2KID = wxUINT32_SWAP_ALWAYS(ip);
-	
+	uint32_t ED2KID = wxUINT32_SWAP_ALWAYS(ip);
+
 	if (theApp->ipfilter->IsFiltered(ED2KID)) {
 		AddDebugLogLineM(false, logKadSearch, wxT("Source ip got filtered"));
 		AddDebugLogLineM(false, logIPFilter, CFormat(wxT("IPfiltered source IP=%s received from Kademlia")) % Uint32toStringIP(ED2KID));
 		return;
 	}
-	
+
 	if( (ip == Kademlia::CKademlia::GetIPAddress() || ED2KID == theApp->GetED2KID()) && tcp == thePrefs::GetPort()) {
 		AddDebugLogLineM(false, logKadSearch, wxT("Trying to add myself as source, ignore"));
 		return;
 	}
-	
+
 	CUpDownClient* ctemp = NULL; 
-	switch( type ) {
+	switch (type) {
 		case 4:
 		case 1: {
-			//NonFirewalled users
+			// NonFirewalled users
 			if(!tcp) {
 				AddDebugLogLineM(false, logKadSearch, CFormat(wxT("Ignored source (IP=%s) received from Kademlia, no tcp port received")) % Uint32toStringIP(ip));
 				return;
@@ -1491,10 +1486,11 @@ void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt12
 				AddDebugLogLineM(false, logIPFilter, CFormat(wxT("Ignored source (IP=%s) received from Kademlia, filtered")) % Uint32toStringIP(ED2KID));
 				return;
 			}
-			ctemp = new CUpDownClient(tcp,ip,0,0,temp,false, true);
+			ctemp = new CUpDownClient(tcp, ip, 0, 0, temp, false, true);
 			ctemp->SetSourceFrom(SF_KADEMLIA);
-			ctemp->SetServerIP(serverip);
-			ctemp->SetServerPort(serverport);
+			// not actually sent or needed for HighID sources
+			//ctemp->SetServerIP(serverip);
+			//ctemp->SetServerPort(serverport);
 			ctemp->SetKadPort(udp);
 			byte cID[16];
 			pcontactID->ToByteArray(cID);
@@ -1502,16 +1498,16 @@ void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt12
 			break;
 		}
 		case 2: {
-			//Don't use this type... Some clients will process it wrong..
+			// Don't use this type... Some clients will process it wrong..
 			break;
 		}
 		case 5:
 		case 3: {
-			//This will be a firewaled client connected to Kad only.
-			//We set the clientID to 1 as a Kad user only has 1 buddy.
-			ctemp = new CUpDownClient(tcp,1,0,0,temp,false, true);
-			//The only reason we set the real IP is for when we get a callback
-			//from this firewalled source, the compare method will match them.
+			// This will be a firewalled client connected to Kad only.
+			// We set the clientID to 1 as a Kad user only has 1 buddy.
+			ctemp = new CUpDownClient(tcp, 1, 0, 0, temp, false, true);
+			// The only reason we set the real IP is for when we get a callback
+			// from this firewalled source, the compare method will match them.
 			ctemp->SetSourceFrom(SF_KADEMLIA);
 			ctemp->SetKadPort(udp);
 			byte cID[16];
@@ -1519,12 +1515,12 @@ void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt12
 			ctemp->SetUserHash(CMD4Hash(cID));
 			pbuddyID->ToByteArray(cID);
 			ctemp->SetBuddyID(cID);
-			ctemp->SetBuddyIP(serverip);
-			ctemp->SetBuddyPort(serverport);
+			ctemp->SetBuddyIP(buddyip);
+			ctemp->SetBuddyPort(buddyport);
 			break;
 		}
 		case 6: {
-			// firewalled source which supports direct udp callback
+			// firewalled source which supports direct UDP callback
 			// if we are firewalled ourself, the source is useless to us
 			if (theApp->IsFirewalled()) {
 				break;
@@ -1534,15 +1530,14 @@ void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt12
 				AddDebugLogLineM(false, logKadSearch, CFormat(wxT("Received Kad source type 6 (direct callback) which has the direct callback flag not set (%s)")) % Uint32toStringIP(ED2KID));
 				break;
 			}
-			
+
 			ctemp = new CUpDownClient(tcp, 1, 0, 0, temp, false, true);
 			ctemp->SetSourceFrom(SF_KADEMLIA);
 			ctemp->SetKadPort(udp);
-			ctemp->SetIP(ED2KID); // need to set the Ip address, which cannot be used for TCP but for UDP
+			ctemp->SetIP(ED2KID); // need to set the IP address, which cannot be used for TCP but for UDP
 			byte cID[16];
 			pcontactID->ToByteArray(cID);
 			ctemp->SetUserHash(CMD4Hash(cID));
-			pbuddyID->ToByteArray(cID);
 		}
 	}
 
@@ -1557,17 +1552,15 @@ void CDownloadQueue::KademliaSearchFile(uint32 searchID, const Kademlia::CUInt12
 
 CPartFile* CDownloadQueue::GetFileByKadFileSearchID(uint32 id) const
 {
-	
 	wxMutexLocker lock( m_mutex );
-	
+
 	for ( uint16 i = 0; i < m_filelist.size(); ++i ) {
 		if ( id == m_filelist[i]->GetKadFileSearchID()) {
 			return m_filelist[ i ];
 		}
 	}
-	
+
 	return NULL;
-	
 }
 
 bool CDownloadQueue::DoKademliaFileRequest()
