@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2005 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -20,24 +20,18 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
 #ifndef DOWNLOADQUEUE_H
 #define DOWNLOADQUEUE_H
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "DownloadQueue.h"
-#endif
-
-#include "Types.h"		// Needed for uint8, uint16, uint32 and uint64
-#include "CMD4Hash.h"	// Needed for CMD4Hash
+#include "MD4Hash.h"		// Needed for CMD4Hash
 #include "ObservableQueue.h"	// Needed for CObservableQueue
+#include "GetTickCount.h" 	// Needed fot GetTickCount
 
-#include <wx/thread.h>	// Needed for wxMutex
 
 #include <deque>
-#include <list>
 
 
 class CSharedFileList;
@@ -45,14 +39,17 @@ class CSearchFile;
 class CPartFile;
 class CUpDownClient;
 class CServer;
-class CSafeMemFile;
+class CMemFile;
 class CKnownFile;
 class CED2KLink;
 class CED2KFileLink;
 class CED2KServerLink;
 class CED2KServerListLink;
+class CPath;
 
-
+namespace Kademlia {
+	class CUInt128;
+}
 
 /**
  * The download queue houses all active downloads.
@@ -73,12 +70,8 @@ public:
 	 */
 	~CDownloadQueue();
 
-	/**
-	 * Loads met-files from the specified directory.
-	 *
-	 * @param path The directory containing the .met files.
-	 */
-	void	LoadMetFiles(const wxString& path);
+	/** Loads met-files from the specified directory. */
+	void	LoadMetFiles(const CPath& path);
 
 	/**
 	 * Main worker function.
@@ -112,7 +105,11 @@ public:
 	 * Returns true if the specified file is on the download-queue.
 	 */
 	bool	IsPartFile(const CKnownFile* file) const;
-
+	
+	/**
+	 * Updates the file's download active time
+	 */
+	void OnConnectionState(bool bConnected);
 	
 	/**
 	 * Starts a new download based on the specified search-result.
@@ -126,6 +123,16 @@ public:
 	void	AddSearchToDownload(CSearchFile* toadd, uint8 category);
 	
 	
+	/**
+	 * Adds an existing partfile to the queue.
+	 *
+	 * @param newfile The file to add.
+	 * @param paused If the file should be stopped when added.
+	 * @param category The category to assign to the file.
+	 */
+	void	AddDownload(CPartFile* newfile, bool paused, uint8 category);
+
+
 	/**
 	 * Removes the specified file from the queue.
 	 *
@@ -133,11 +140,6 @@ public:
 	 */
 	void	RemoveFile(CPartFile* toremove);
 	
-	/**
-	 * This function clears the sources (and requested block) of all queued files.
-	 */
-	void	ClearAllSources();
-
 	
 	/**
 	 * Saves the source-seeds of every file on the queue.
@@ -223,11 +225,6 @@ public:
 	void	StartNextFile(CPartFile* oldfile);
 
 
-	/**
-	 * Resets the category of all files with the specified category.
-	 */
-	void	ResetCatParts(uint8 cat);
-
 	/**
 	 * Sets the priority of all files with the specified category.
 	 */
@@ -238,12 +235,6 @@ public:
 	 */
 	void	SetCatStatus(uint8 cat, int newstatus);
 
-
-	/**
-	 * Returns the current download-rate.
-	 */
-	float	GetKBps() const;
-
 	/**
 	 * Returns the current number of queued files.
 	 */
@@ -259,20 +250,17 @@ public:
 	 */
 	uint16	GetPausedFileCount() const;
 
-	/**
-	 * Updates the array with the number of sources and transfering sources.
-	 *
-	 * @param results Must be at least 2 uint32s long.
-	 */
-	void	GetDownloadStats(uint32 results[]) const;
 
-	
 	/**
 	 * This function is called when a DNS lookup is finished.
 	 */
 	void	OnHostnameResolved(uint32 ip);
 
 
+	/**
+	 * Adds an ed2k or magnet link to download queue.
+	 */
+	bool	AddLink( const wxString& link, int category = 0 );
 
 	bool	AddED2KLink( const wxString& link, int category = 0 );
 	bool	AddED2KLink( const CED2KLink* link, int category = 0 );
@@ -297,6 +285,19 @@ public:
 	 */
 	void	StopUDPRequests();
 	
+	/* Kad Stuff */
+	
+	/**
+	 * Add a Kad source to a download
+	 */
+	 void	KademliaSearchFile(uint32_t searchID, const Kademlia::CUInt128* pcontactID, const Kademlia::CUInt128* pkadID, uint8_t type, uint32_t ip, uint16_t tcp, uint16_t udp, uint32_t buddyip, uint16_t buddyport, uint8_t byCryptOptions);
+	
+	CPartFile* GetFileByKadFileSearchID(uint32 id) const;
+	
+	bool	DoKademliaFileRequest();
+	
+	void	SetLastKademliaFileRequest()	{lastkademliafilerequest = ::GetTickCount();}
+	
 private:
 	/**
 	 * This function initializes new observers with the current contents of the queue.
@@ -309,21 +310,8 @@ private:
 	 */
 	void	DoSortByPriority();
 	
-	/**
-	 * Adds an existing partfile to the queue.
-	 *
-	 * @param newfile The file to add.
-	 * @param paused If the file should be stopped when added.
-	 * @param category The category to assign to the file.
-	 */
-	void	AddDownload(CPartFile* newfile, bool paused, uint8 category);
-
-	/**
-	 * Checks that there is enough free spaces for temp-files at that specified path.
-	 *
-	 * @param path The path to a folder containing temp-files.
-	 */
-	void	CheckDiskspace( const wxString& path );
+	/** Checks that there is enough free spaces for temp-files at that specified path. */
+	void	CheckDiskspace(const CPath& path);
 
 	/**
 	 * Parses all links in the ED2KLink file and resets it.
@@ -340,9 +328,9 @@ private:
 	
 	bool	SendNextUDPPacket();
 	int		GetMaxFilesPerUDPServerPacket() const;
-	bool	SendGlobGetSourcesUDPPacket(CSafeMemFile& data);
+	bool	SendGlobGetSourcesUDPPacket(CMemFile& data);
 	
-	void 	AddToResolve(const CMD4Hash& fileid, const wxString& pszHostname, uint16 port);
+	void 	AddToResolve(const CMD4Hash& fileid, const wxString& pszHostname, uint16 port, const wxString& hash, uint8 cryptoptions);
 
 	//! The mutex assosiated with this class, mutable to allow for const functions.
 	mutable wxMutex m_mutex;
@@ -371,6 +359,10 @@ private:
 		wxString strHostname;
 		//! The user-port of the source.
 		uint16 port;
+		//! The hash of the source
+		wxString hash;
+		//! The cryptoptions for the source
+		uint8 cryptoptions;
 	};
 
 	std::deque<Hostname_Entry>	m_toresolve;
@@ -385,6 +377,11 @@ private:
 	
 	//! Observer used to keep track of which file to send UDP requests for
 	CQueueObserver<CPartFile*>	m_queueFiles;
+	
+	/* Kad Stuff */
+	uint32		lastkademliafilerequest;
+	
 };
 
 #endif // DOWNLOADQUEUE_H
+// File_checked_for_headers
