@@ -1,9 +1,9 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 Angel Vidal (Kry) ( kry@amule.org )
-// Copyright (c) 2003-2008 Patrizio Bassi (Hetfield) ( hetfield@amule.org )
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 Angel Vidal (Kry) ( kry@amule.org )
+// Copyright (c) 2003-2009 Patrizio Bassi (Hetfield) ( hetfield@amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
 // or contributed by third-party developers are copyrighted by their
@@ -562,15 +562,6 @@ wxMenu* CMuleTrayIcon::CreatePopupMenu()
 
 void CMuleTrayIcon::SwitchShow(wxTaskBarIconEvent&)
 {
-	if ( !theApp->amuledlg->IsIconized() ) {
-		theApp->amuledlg->Iconize(true);
-		if (thePrefs::DoMinToTray()) {
-			theApp->amuledlg->Show(false);
-		}
-	} else {
-		theApp->amuledlg->Iconize(false);
-		theApp->amuledlg->Show(true);
-		theApp->amuledlg->Raise();
-	}
+	theApp->amuledlg->DoIconize(theApp->amuledlg->IsShown());
 }
 // File_checked_for_headers
