@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -109,17 +109,15 @@ wxString CastItoXBytes( uint64 count )
 {
 
 	if (count < 1024)
-		return wxString::Format( wxT("%.0f "), (float)(uint32)count) + wxPLURAL("byte", "bytes", count) ;
+		return wxString::Format( wxT("%u "), (unsigned)count) + wxPLURAL("byte", "bytes", count) ;
 	else if (count < 1048576)
-		return wxString::Format( wxT("%.0f "), (float)(uint32)count/1024) + _("kB") ;
+		return wxString::Format( wxT("%u "), (unsigned)count >> 10) + _("kB") ;
 	else if (count < 1073741824)
 		return wxString::Format( wxT("%.2f "), (float)(uint32)count/1048576) + _("MB") ;
 	else if (count < 1099511627776LL)
 		return wxString::Format( wxT("%.2f "), (float)((uint32)(count/1024))/1048576) + _("GB") ;
 	else
 		return wxString::Format( wxT("%.3f "), (float)count/1099511627776LL) + _("TB") ;
-
-	return _("ERROR");
 }
 
 
@@ -134,10 +132,8 @@ wxString CastItoIShort(uint64 count)
 		return wxString::Format(wxT("%.2f"),(float)(uint32)count/1000000) + _("M") ;
 	else if (count < 1000000000000LL)
 		return wxString::Format(wxT("%.2f"),(float)((uint32)(count/1000))/1000000) + _("G") ;
-	else if (count < 1000000000000000LL)
+	else
 		return wxString::Format(wxT("%.2f"),(float)count/1000000000000LL) + _("T");
-
-	return _("ERROR");
 }
 
 
@@ -190,8 +186,6 @@ wxString CastSecondsToHM(uint64 count, uint16 msecs)
 			(count % 86400)/3600,
 			(count % 3600)/60) + _("hours");
 	}
-		
-	return _("ERROR");
 }
 
 
@@ -501,7 +495,7 @@ unsigned int DecodeBase32(const wxString &base32Buffer, unsigned int base32BufLe
  * Base64 encoding/decoding command line filter
  *
  * Copyright (c) 2002 Matthias Gaertner 29.06.2002
- * Adapted by (C) 2005-2008 Phoenix to use wxWidgets.
+ * Adapted by (C) 2005-2009 Phoenix to use wxWidgets.
  *
  */
 static const wxString to_b64(
@@ -1065,13 +1059,20 @@ void InitCustomLanguages()
 	CustomLanguage.CanonicalName = wxT("it_NA");
 	CustomLanguage.Description = wxT("sNeo's Custom Napolitan Language");
 	wxLocale::AddLanguage(CustomLanguage);
+
+	CustomLanguage.Language = wxLANGUAGE_ASTURIAN;
+	CustomLanguage.CanonicalName = wxT("ast_ES");
+	CustomLanguage.Description = wxT("Asturian");
+	wxLocale::AddLanguage(CustomLanguage);
 }
 
 
 void InitLocale(wxLocale& locale, int language)
 {
 	int language_flags = 0;
-	if (language != wxLANGUAGE_CUSTOM && language != wxLANGUAGE_ITALIAN_NAPOLITAN) {
+	if ((wxLANGUAGE_CUSTOM != language) && 
+		(wxLANGUAGE_ASTURIAN != language) &&
+		(wxLANGUAGE_ITALIAN_NAPOLITAN != language)) {
 		language_flags = wxLOCALE_LOAD_DEFAULT | wxLOCALE_CONV_ENCODING;
 	}
 	
