@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -83,7 +83,7 @@
 #include "UserEvents.h"
 
 #ifdef ENABLE_UPNP
-#include "UPnP.h"			// Needed for UPnP
+#include "UPnPBase.h"			// Needed for UPnP
 #endif
 
 #ifdef __WXMAC__
@@ -386,7 +386,7 @@ std::pair<bool, CPath> CheckMuleDirectory(const wxString& desc, const CPath& dir
 	} 
 	
 	theApp->ShowAlert(msg, wxT("Fatal error."), wxICON_ERROR | wxOK);
-	return std::pair<bool, wxString>(false, wxEmptyString);
+	return std::pair<bool, CPath>(false, CPath(wxEmptyString));
 }
 
 
@@ -431,7 +431,7 @@ bool CamuleApp::OnInit()
 	OSType = OSDescription.BeforeFirst( wxT(' ') );
 	if ( OSType.IsEmpty() ) {
 		OSType = wxT("Unknown");
-	}	
+	}
 
 	// Handle uncaught exceptions
 	InstallMuleExceptionHandler();
@@ -506,9 +506,7 @@ bool CamuleApp::OnInit()
 	}
 	
 	if ( cmdline.Found(wxT("version")) ) {
-		printf("%s (OS: %s)\n",
-			(const char*)unicode2char(GetFullMuleVersion()),
-			(const char*)unicode2char(OSType));
+		printf("%s (OS: %s)\n", strFullMuleVersion, (const char*)unicode2char(OSType));
 		
 		return false;
 	}
@@ -522,8 +520,7 @@ bool CamuleApp::OnInit()
 	}
 #endif
 
-
-	printf("Initialising aMule\n");
+	printf("Initialising %s\n", strFullMuleVersion);
 
 	// Ensure that "~/.aMule/" is accessible.
 	if (!CheckMuleDirectory(wxT("configuration"), CPath(ConfigDir), wxEmptyString).first) {
@@ -544,9 +541,11 @@ bool CamuleApp::OnInit()
 #else
 	printf("Checking if there is an instance already running...\n");
 
-	m_singleInstance = new wxSingleInstanceChecker(wxT("muleLock"), ConfigDir);
-	if (m_singleInstance->IsAnotherRunning()) {
+	m_singleInstance = new wxSingleInstanceChecker();
+	if (m_singleInstance->Create(wxT("muleLock"), ConfigDir)
+		&& m_singleInstance->IsAnotherRunning()) {
 		printf("There is an instance of aMule already running\n");
+		printf("%s", (const char*)unicode2UTF8(wxString(CFormat(wxT("(lock file: %s%s)")) % ConfigDir % wxT("muleLock"))));
 		
 		// This is very tricky. The most secure way to communicate is via ED2K links file
 		wxTextFile ed2kFile(ConfigDir + wxT("ED2KLinks"));
@@ -602,6 +601,9 @@ bool CamuleApp::OnInit()
 		return false;
 	}
 
+	// This cannot be translated, as localization is not set up yet.
+	AddLogLineM(false, wxT("Starting ") + FullMuleVersion);
+
 	// Load Preferences
 	CPreferences::BuildItemList(ConfigDir);
 	CPreferences::LoadAllItems( wxConfigBase::Get() );
@@ -644,24 +646,6 @@ bool CamuleApp::OnInit()
 		printf("Password set and external connections enabled.\n");
 	}
 	
-	// Display notification on new version or first run
-	wxTextFile vfile( ConfigDir + wxT("lastversion") );
-	wxString newMule(wxT( VERSION ));
-	
-	// Test if there's any new version
-	if (thePrefs::CheckNewVersion()) {
-		// We use the thread base because I don't want a dialog to pop up.
-		CHTTPDownloadThread* version_check = 
-			new CHTTPDownloadThread(wxT("http://amule.sourceforge.net/lastversion"),
-				theApp->ConfigDir + wxT("last_version_check"), HTTP_VersionCheck, false);
-		version_check->Create();
-		version_check->Run();
-	}
-
-	if ( !wxFileExists( vfile.GetName() ) ) {
-		vfile.Create();
-	}
-
 #ifndef __WXMSW__
 	if (getuid() == 0) {
 		wxString msg = 
@@ -678,6 +662,14 @@ bool CamuleApp::OnInit()
 	}
 #endif
 	
+	// Display notification on new version or first run
+	wxTextFile vfile( ConfigDir + wxT("lastversion") );
+	wxString newMule(wxT( VERSION ));
+	
+	if ( !wxFileExists( vfile.GetName() ) ) {
+		vfile.Create();
+	}
+
 	if ( vfile.Open() ) {
 		// Check if this version has been run before
 		bool found = false;
@@ -735,6 +727,16 @@ bool CamuleApp::OnInit()
 		printf("\n%s\n", (const char *)unicode2char(msg));
 	}
 
+	// Test if there's any new version
+	if (thePrefs::CheckNewVersion()) {
+		// We use the thread base because I don't want a dialog to pop up.
+		CHTTPDownloadThread* version_check = 
+			new CHTTPDownloadThread(wxT("http://amule.sourceforge.net/lastversion"),
+				theApp->ConfigDir + wxT("last_version_check"), HTTP_VersionCheck, false);
+		version_check->Create();
+		version_check->Run();
+	}
+
 	// Create main dialog, or fork to background (daemon).
 	InitGui(geometry_enabled, geom_string);
 	
@@ -845,10 +847,7 @@ bool CamuleApp::OnInit()
 		} else {
 			delete p;
 			ShowAlert(_(
-				"You requested to run web server on startup, "
-				"but the amuleweb binary cannot be run. "
-				"Please install the package containing aMule web server, "
-				"or compile aMule using --enable-webserver and run make install"),
+				"You requested to run web server on startup, but the amuleweb binary cannot be run. Please install the package containing aMule web server, or compile aMule using --enable-webserver and run make install"),
 				_("ERROR"), wxOK | wxICON_ERROR);
 		}
 	}
@@ -1031,6 +1030,7 @@ wxString CamuleApp::CreateMagnetLink(const CAbstractFile *f)
 
 	uri.AddField(wxT("dn"), f->GetFileName().Cleanup(false).GetPrintable());
 	uri.AddField(wxT("xt"), wxString(wxT("urn:ed2k:")) + f->GetFileHash().Encode().Lower());
+	uri.AddField(wxT("xt"), wxString(wxT("urn:ed2khash:")) + f->GetFileHash().Encode().Lower());
 	uri.AddField(wxT("xl"), wxString::Format(wxT("%") wxLongLongFmtSpec wxT("u"), f->GetFileSize()));
 
 	return uri.GetLink();
@@ -1089,10 +1089,11 @@ wxString CamuleApp::CreateED2kAICHLink(const CKnownFile* f)
 	wxString strURL = CreateED2kLink(f);
 	// Append the AICH info
 	if (f->HasProperAICHHashSet()) {
-	     	strURL << wxT("|h=") << f->GetAICHMasterHash() << wxT("|/");
+		strURL.RemoveLast();		// remove trailing '/'
+		strURL << wxT("h=") << f->GetAICHMasterHash() << wxT("|/");
 	}	
 
-	// Result is "ed2k://|file|<filename>|<size>|<hash>|/|h=<AICH master hash>|/"
+	// Result is "ed2k://|file|<filename>|<size>|<hash>|h=<AICH master hash>|/"
 	return strURL;
 }
 
@@ -1239,7 +1240,7 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 
 	// amule version
 #ifdef SVNDATE
-	amulesig_out.AddLine(wxT(VERSION " " SVNDATE));
+	amulesig_out.AddLine(wxT(VERSION) wxT(" ") wxT(SVNDATE));
 #else
 	amulesig_out.AddLine(wxT(VERSION));
 #endif
