@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -36,7 +36,9 @@
 #include <wx/tokenzr.h>
 #include <wx/wfstream.h>
 #include <wx/zipstrm.h>
+#include <wx/sysopt.h>
 #include <wx/wupdlock.h>	// Needed for wxWindowUpdateLocker
+#include <wx/utils.h>		// Needed for wxBusyCursor
 
 #include <common/EventIDs.h>
 
@@ -69,9 +71,7 @@
 #include "StatisticsDlg.h"	// Needed for CStatisticsDlg
 #include "TerminationProcess.h"	// Needed for CTerminationProcess
 #include "TransferWnd.h"	// Needed for CTransferWnd
-#ifndef CLIENT_GUI
-#include "PartFileConvert.h"
-#endif
+#include "PartFileConvertDlg.h"
 
 #ifndef __WXMSW__
 #include "aMule.xpm"
@@ -94,9 +94,7 @@ BEGIN_EVENT_TABLE(CamuleDlg, wxFrame)
 	EVT_TOOL(ID_ABOUT, CamuleDlg::OnAboutButton)
 
 	EVT_TOOL(ID_BUTTONNEWPREFERENCES, CamuleDlg::OnPrefButton)
-#ifndef CLIENT_GUI
 	EVT_TOOL(ID_BUTTONIMPORT, CamuleDlg::OnImportButton)
-#endif
 
 	EVT_TOOL(ID_BUTTONCONNECT, CamuleDlg::OnBnConnect)
 
@@ -104,7 +102,6 @@ BEGIN_EVENT_TABLE(CamuleDlg, wxFrame)
 	EVT_ICONIZE(CamuleDlg::OnMinimize)
 
 	EVT_BUTTON(ID_BUTTON_FAST, CamuleDlg::OnBnClickedFast)
-	EVT_BUTTON(IDC_SHOWSTATUSTEXT, CamuleDlg::OnBnStatusText)
 
 	EVT_TIMER(ID_GUI_TIMER_EVENT, CamuleDlg::OnGUITimer)
 
@@ -189,15 +186,9 @@ m_clientSkinNames(CLIENT_SKIN_SIZE)
 	wxInitAllImageHandlers();
 	Apply_Clients_Skin();
 	
-	bool override_where = where != wxDefaultPosition;
-	bool override_size =
-		dlg_size.x != DEFAULT_SIZE_X ||
-		dlg_size.y != DEFAULT_SIZE_Y;
-	if (!LoadGUIPrefs(override_where, override_size)) {
-		// Prefs not loaded for some reason, exit
-		AddLogLineM( true, wxT("Error! Unable to load Preferences") );
-		return;
-	}
+#ifdef __WXMSW__
+       wxSystemOptions::SetOption(wxT("msw.remap"), 0);
+#endif
 
 	SetIcon(wxICON(aMule));
 
@@ -252,6 +243,19 @@ m_clientSkinNames(CLIENT_SKIN_SIZE)
 	SetActiveDialog(DT_TRANSFER_WND, m_transferwnd);
 	m_wndToolbar->ToggleTool(ID_BUTTONTRANSFER, true );
 
+	bool override_where = (where != wxDefaultPosition);
+	bool override_size = (
+		(dlg_size.x != DEFAULT_SIZE_X) ||
+		(dlg_size.y != DEFAULT_SIZE_Y) );
+	if (!LoadGUIPrefs(override_where, override_size)) {
+		// Prefs not loaded for some reason, exit
+		AddLogLineM( true, wxT("Error! Unable to load Preferences") );
+		return;
+	}
+
+	// Prepare the dialog, sets the splitter-position (AFTER window size is set)
+	m_transferwnd->Prepare();
+
 	m_is_safe_state = true;
 
 	// Init statistics stuff, better do it asap
@@ -282,12 +286,12 @@ m_clientSkinNames(CLIENT_SKIN_SIZE)
 	wxASSERT(logs_notebook->GetPageCount() == 4);
 	wxASSERT(networks_notebook->GetPageCount() == 2);
 	
-	for (int i = 0; i < logs_notebook->GetPageCount(); ++i) {
+	for (size_t i = 0; i < logs_notebook->GetPageCount(); ++i) {
 		m_logpages[i].page = logs_notebook->GetPage(i);
 		m_logpages[i].name = logs_notebook->GetPageText(i);
 	}
 
-	for (int i = 0; i < networks_notebook->GetPageCount(); ++i) {
+	for (size_t i = 0; i < networks_notebook->GetPageCount(); ++i) {
 		m_networkpages[i].page = networks_notebook->GetPage(i);
 		m_networkpages[i].name = networks_notebook->GetPageText(i);
 	}
@@ -462,7 +466,7 @@ void CamuleDlg::OnAboutButton(wxCommandEvent& WXUNUSED(ev))
 		_(" Forum: http://forum.amule.org \n") << 
 		_(" FAQ: http://wiki.amule.org \n\n") <<
 		_(" Contact: admin@amule.org (administrative issues) \n") <<
-		_(" Copyright (C) 2003-2008 aMule Team \n\n") <<
+		_(" Copyright (C) 2003-2009 aMule Team \n\n") <<
 		_(" Part of aMule is based on \n") <<
 		_("Kademlia: Peer-to-peer routing based on the XOR metric.\n") <<
 		_(" Copyright (C) 2002 Petar Maymounkov\n") <<
@@ -477,6 +481,7 @@ void CamuleDlg::OnAboutButton(wxCommandEvent& WXUNUSED(ev))
 void CamuleDlg::OnPrefButton(wxCommandEvent& WXUNUSED(ev))
 {
 	if (m_is_safe_state) {
+		wxBusyCursor busyCursor;
 		if (m_prefsDialog == NULL) {
 			m_prefsDialog = new PrefsUnifiedDlg(this);
 		}
@@ -488,14 +493,13 @@ void CamuleDlg::OnPrefButton(wxCommandEvent& WXUNUSED(ev))
 }
 
 
-#ifndef CLIENT_GUI
 void CamuleDlg::OnImportButton(wxCommandEvent& WXUNUSED(ev))
 {
-	if ( m_is_safe_state ) {
-		CPartFileConvert::ShowGUI(NULL);
+	if (m_is_safe_state) {
+		CPartFileConvertDlg::ShowGUI(NULL);
 	}
 }
-#endif
+
 
 CamuleDlg::~CamuleDlg()
 {
@@ -555,16 +559,6 @@ void CamuleDlg::OnBnConnect(wxCommandEvent& WXUNUSED(evt))
 }
 
 
-void CamuleDlg::OnBnStatusText(wxCommandEvent& WXUNUSED(evt))
-{
-	wxString line = CastChild(wxT("infoLabel"), wxStaticText)->GetLabel();
-
-	if (!line.IsEmpty()) {
-		wxMessageBox(line, wxString(_("Status text")), wxOK|wxICON_INFORMATION, this);
-	}
-}
-
-
 void CamuleDlg::ResetLog(int id)
 {
 	wxTextCtrl* ct = CastByID(id, m_serverwnd, wxTextCtrl);
@@ -597,11 +591,14 @@ void CamuleDlg::AddLogLine(bool addtostatusbar, const wxString& line)
 			ct->AppendText( wxT("\n") );
 		} else {
 			// Bold critical log-lines
+			// Windows doesn't support this feature, and it causes GDI resource leaks
+#ifndef __WXMSW__
 			wxTextAttr style = ct->GetDefaultStyle();
 			wxFont font = style.GetFont();
 			font.SetWeight(addtostatusbar ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL);
 			style.SetFont(font);
 			ct->SetDefaultStyle(style);
+#endif
 			
 			// Split multi-line messages into individual lines
 			wxStringTokenizer tokens( bufferline, wxT("\n") );		
@@ -621,6 +618,7 @@ void CamuleDlg::AddLogLine(bool addtostatusbar, const wxString& line)
 		wxStaticText* text = CastChild( wxT("infoLabel"), wxStaticText );
 		// Only show the first line if multiple lines
 		text->SetLabel( bufferline.BeforeFirst( wxT('\n') ) );
+		text->SetToolTip( bufferline );
 		text->GetParent()->Layout();
 	}
 	
@@ -641,7 +639,7 @@ void CamuleDlg::AddServerMessageLine(wxString& message)
 }
 
 
-void CamuleDlg::ShowConnectionState()
+void CamuleDlg::ShowConnectionState(bool skinChanged)
 {
 	static wxImageList status_arrows(16,16,true,0);
 	if (!status_arrows.GetImageCount()) {
@@ -743,7 +741,7 @@ void CamuleDlg::ShowConnectionState()
 		currentState = ECS_Disconnected;
 	}
 
-	if (currentState != s_oldState) {
+	if ( (true == skinChanged) || (currentState != s_oldState)) {
 		wxWindowUpdateLocker freezer(m_wndToolbar);
 		
 		wxToolBarToolBase* toolbarTool = m_wndToolbar->RemoveTool(ID_BUTTONCONNECT);
@@ -965,19 +963,21 @@ bool CamuleDlg::SaveGUIPrefs()
 	// The section where to save in in file
 	wxString section = wxT("/Razor_Preferences/");
 
-	// Main window location and size
-	int x1, y1, x2, y2;
-	GetPosition(&x1, &y1);
-	GetSize(&x2, &y2);
+	if (!IsIconized()) {
+		// Main window location and size
+		int x1, y1, x2, y2;
+		GetPosition(&x1, &y1);
+		GetSize(&x2, &y2);
 
-	// Saving window size and position
-	config->Write(section+wxT("MAIN_X_POS"), (long) x1);
-	config->Write(section+wxT("MAIN_Y_POS"), (long) y1);
+		// Saving window size and position
+		config->Write(section+wxT("MAIN_X_POS"), (long) x1);
+		config->Write(section+wxT("MAIN_Y_POS"), (long) y1);
 
-	config->Write(section+wxT("MAIN_X_SIZE"), (long) x2);
-	config->Write(section+wxT("MAIN_Y_SIZE"), (long) y2);
+		config->Write(section+wxT("MAIN_X_SIZE"), (long) x2);
+		config->Write(section+wxT("MAIN_Y_SIZE"), (long) y2);
 
-	config->Write(section+wxT("Maximized"), (long) (IsMaximized() ? 1 : 0));
+		config->Write(section+wxT("Maximized"), (long) (IsMaximized() ? 1 : 0));
+	}
 
 	// Saving sash position of splitter in server window
 	config->Write(section+wxT("SRV_SPLITTER_POS"), (long) m_srv_split_pos);
@@ -992,39 +992,39 @@ bool CamuleDlg::SaveGUIPrefs()
 
 void CamuleDlg::DoIconize(bool iconize) 
 {
-	// Evil Hack: check if the mouse is inside the window
-#ifndef __WINDOWS__
-	if (GetScreenRect().Contains(wxGetMousePosition()))
-#endif
-	{
-		if (m_wndTaskbarNotifier && thePrefs::DoMinToTray()) {
-			if (iconize) {
-				// Skip() will do it.
-				//Iconize(true);
-				if (SafeState()) {
-					Show(false);
-				}
-			} else {
-				Show(true);
-				Raise();
+	if (m_wndTaskbarNotifier && thePrefs::DoMinToTray()) {
+		if (iconize) {
+			// Skip() will do it.
+			//Iconize(true);
+			if (SafeState()) {
+				Show(false);
 			}
 		} else {
-			// Will be done by Skip();
-			//Iconize(iconize);
+			Show(true);
+			Raise();
 		}
+	} else {
+		// Will be done by Skip();
+		//Iconize(iconize);
 	}
 }
 
 void CamuleDlg::OnMinimize(wxIconizeEvent& evt)
 {
-	if (m_prefsDialog && m_prefsDialog->IsShown()) {
-		// Veto.
-	} else {
-		if (m_wndTaskbarNotifier) {
-			DoIconize(evt.Iconized());
+// Evil Hack: check if the mouse is inside the window
+#ifndef __WXMSW__
+       if (GetScreenRect().Contains(wxGetMousePosition()))
+#endif
+       {
+		if (m_prefsDialog && m_prefsDialog->IsShown()) {
+			// Veto.
+		} else {
+			if (m_wndTaskbarNotifier) {
+				DoIconize(evt.Iconized());
+			}
+			evt.Skip();
 		}
-		evt.Skip();
-	}
+       }
 }
 
 void CamuleDlg::OnGUITimer(wxTimerEvent& WXUNUSED(evt))
@@ -1328,7 +1328,7 @@ void CamuleDlg::Apply_Toolbar_Skin(wxToolBar *wndToolbar)
 	wndToolbar->Realize();
 	
 	// Updates the "Connect" button, and so on.
-	ShowConnectionState();
+	ShowConnectionState(true);
 }
 
 
