@@ -1,9 +1,9 @@
 //
 // This file is part of the aMule Project.
 //  
-// Copyright (c) 2004-2008 shakraw ( shakraw@users.sourceforge.net )
-// Copyright (c) 2003-2008 Kry ( elkry@sourceforge.net / http://www.amule.org )
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2004-2009 shakraw ( shakraw@users.sourceforge.net )
+// Copyright (c) 2003-2009 Kry ( elkry@sourceforge.net / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
 // or contributed by third-party developers are copyrighted by their
@@ -92,7 +92,7 @@ void CSocketSet::AddSocket(GSocket *socket)
         return;
     }
 
-    wxASSERT( (fd > 2) && (fd < FD_SETSIZE) );
+    wxASSERT( (fd >= 0) && (fd < FD_SETSIZE) );
     
     if ( m_gsocks[fd] ) {
         return;
@@ -113,7 +113,7 @@ void CSocketSet::RemoveSocket(GSocket *socket)
         return;
     }
     
-    wxASSERT( (fd > 2) && (fd < FD_SETSIZE) );
+    wxASSERT( (fd >= 0) && (fd < FD_SETSIZE) );
     
     int i = m_fd_idx[fd];
     if ( i == 0xffff ) {
