@@ -1,8 +1,8 @@
 //
 // This file is part of the aMule Project.
 
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
-// Copyright (C) 2005-2008 Froenchenko Leonid ( lfroen@amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (C) 2005-2009 Froenchenko Leonid ( lfroen@amule.org )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
 // or contributed by third-party developers are copyrighted by their
@@ -23,13 +23,17 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
+#ifdef HAVE_CONFIG_H
+#      include "config.h"
+#endif
 
 #include <string> // Do_not_auto_remove (g++-4.0.1)
 
-#include <sys/types.h>
+#ifdef HAVE_SYS_TYPES_H
+#      include <sys/types.h>
+#endif
 #include <regex.h>
 
-#include "config.h"
 #include "WebServer.h"
 #include <ec/cpp/ECSpecialTags.h>
 
